import request from '@/utils/request'
import { praseStrEmpty } from "@/utils/common-util";
import Qs from 'qs'
import md5 from 'js-md5';
// 查询用户列表
export function listUser(query) {
  return request({
    url: '/v1/system/user/list',
    method: 'get',
    params: query
  })
}
// 获取用户列表（用于用户选择，做数据权限过滤）
export function listUserSelectByPermi(query) {
  return request({
    url: '/v1/system/user/listUserSelectByPermi',
    method: 'get',
    params: query
  })
}
// 获取用户列表（用于用户选择，不做数据权限过滤）
export function listUserSelect(query) {
  return request({
    url: '/v1/system/user/listUserSelect',
    method: 'get',
    params: query
  })
}
// 查询用户详细
export function getUser(userId) {
  return request({
    url: '/v1/system/user/' + praseStrEmpty(userId),
    method: 'get'
  })
}

// 新增用户
export function addUser(data) {
  const user = JSON.parse(JSON.stringify(data))
  user.password = md5(user.userName + user.password)
  return request({
    url: '/v1/system/user',
    method: 'post',
    data: user
  })
}

// 修改用户
export function updateUser(data) {
  return request({
    url: '/v1/system/user',
    method: 'put',
    data: data
  })
}

// 删除用户
export function delUser(userId) {
  return request({
    url: '/v1/system/user/' + userId,
    method: 'delete'
  })
}

// 导出用户
export function exportUser(query) {
  return request({
    url: '/v1/system/user/export',
    method: 'get',
    params: query
  })
}

// 用户密码重置
export function resetUserPwd(userId, username, password) {
  const data = {
    userId: userId,
    password: md5(username + password)
  }
  return request({
    url: '/v1/system/user/resetPwd',
    method: 'put',
    data: data
  })
}

// 用户状态修改
export function changeUserStatus(userId, status) {
  const data = {
    userId,
    status
  }
  return request({
    url: '/v1/system/user/changeStatus',
    method: 'put',
    data: data
  })
}

// 查询用户个人信息
export function getUserProfile() {
  return request({
    url: '/v1/system/user/profile',
    method: 'get'
  })
}

// 修改用户个人信息
export function updateUserProfile(data) {
  return request({
    url: '/v1/system/user/profile',
    method: 'put',
    data: data
  })
}

// 用户密码重置
export function updateUserPwd(username, oldPassword, newPassword) {
  return request({
    url: '/v1/system/user/profile/updatePwd',
    method: 'put',
    data:{
      oldPassword: md5(username + oldPassword),
      newPassword: md5(username + newPassword)
    }
  })
}

// 用户头像上传
export function uploadAvatar(data) {
  return request({
    url: '/v1/system/user/profile/avatar',
    method: 'post',
    data: data
  })
}

// 下载用户导入模板
export function importTemplate() {
  return request({
    url: '/v1/system/user/importTemplate',
    method: 'get'
  })
}

// 查询授权角色
export function getAuthRole(userId) {
  return request({
    url: '/v1/system/user/authRole/' + userId,
    method: 'get'
  })
}

// 保存授权角色
export function updateAuthRole(data) {
  return request({
    url: '/v1/system/user/authRole',
    method: 'put',
    params: data
  })
}
